#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri May 14 10:35:42 2021

@author: fsvbach
"""

import pandas as pd
import numpy as np

from openTSNE import TSNE as openTSNE
from sklearn.manifold import TSNE as skleTSNE

from .Distances import GaussianWassersteinDistance, WassersteinDistanceMatrix
from .utils import Dataset2Gaussians

def ComputeTSNE(D, seed=None, perplexity=30, sklearn=False, trafo=None):
    if sklearn:
        tsne = skleTSNE(metric='precomputed', 
                    square_distances=True, 
                    random_state=seed)
        embedding = tsne.fit_transform(D)
    else:
        tsne = openTSNE(metric='precomputed', 
                    initialization ='random', 
                    negative_gradient_method='bh',
                    random_state  =seed,
                    perplexity    = perplexity)
        embedding = tsne.fit(D)
    
    if trafo is None:
        trafo = np.eye(2)

    embedding =  pd.DataFrame( embedding @ trafo, 
                 index=D.index,
                 columns = ['x','y'])
    return embedding

    
def TSNE(X, y=None, seed=None, method='gaussian', w=.5):
    if y:
        X = pd.DataFrame(X, index=y)
    assert isinstance(X, pd.DataFrame)
    
    if method == 'gaussian':
        Gaussians = Dataset2Gaussians(X)
        GWD       = GaussianWassersteinDistance(Gaussians)
        embedding = ComputeTSNE(GWD.matrix(w=w), seed=seed)
        
    elif method == 'exact':
        D = WassersteinDistanceMatrix(X)
        embedding = ComputeTSNE(D, seed=seed)
    
    else:
        raise AssertionError("Please type method='gaussian' or method='exact'")
    
    return embedding
        
    


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__version__ = "1.0.2"
__author__ = 'Fynn Bachmann'
__credits__ = 'Philipp Hennig, Dmitry Kobak'


from .Distances import *
from .Datasets import *
from .Embedding import * 
from .Evaluation import *
from .utils import *
from .Visualization import *





from setuptools import setup
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()


setup(
    name='WassersteinTSNE',
    version='1.0.6',    
    description='A package for dimensionality reduction of probability distributions',
    url='https://github.com/fsvbach/WassersteinTSNE',
    author='Fynn Bachmann, Philipp Hennig, Dmitry Kobak',
    author_email='fynn.bachmann@uni-hamburg.de',
    license='MIT',
    packages=['WassersteinTSNE'],
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=['numpy',
                      'scipy',
                      'pandas',
                      'openTSNE',
                      'scikit-learn',
                      'igraph',
                      'leidenalg',
                      'matplotlib',                    
                      ],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
